aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--CMakeLists.txt2
-rw-r--r--Makefile.am6
-rw-r--r--cmake/modules/FindOS_X_FRAMEWORKS.cmake6
-rw-r--r--cmakeconfig.h.in2
-rw-r--r--configure.ac10
-rw-r--r--ui/gtk/webbrowser.c6
-rw-r--r--wsutil/CMakeLists.txt2
-rw-r--r--wsutil/Makefile.am4
-rw-r--r--wsutil/os_version_info.c10
9 files changed, 24 insertions, 24 deletions
diff --git a/CMakeLists.txt b/CMakeLists.txt
index 86e4614197..5b27af5d4b 100644
--- a/CMakeLists.txt
+++ b/CMakeLists.txt
@@ -1155,7 +1155,7 @@ if(APPLE)
# We assume that APPLE means macOS so that we have the macOS
# frameworks.
#
- set(HAVE_OS_X_FRAMEWORKS 1)
+ set(HAVE_MACOS_FRAMEWORKS 1)
FIND_LIBRARY (APPLE_APPLICATION_SERVICES_LIBRARY ApplicationServices)
FIND_LIBRARY (APPLE_CORE_FOUNDATION_LIBRARY CoreFoundation)
FIND_LIBRARY (APPLE_SYSTEM_CONFIGURATION_LIBRARY SystemConfiguration)
diff --git a/Makefile.am b/Makefile.am
index da3bab3341..d9294b5b00 100644
--- a/Makefile.am
+++ b/Makefile.am
@@ -988,7 +988,7 @@ libtool: $(LIBTOOL_DEPS)
#
install-data-local:
if BUILDING_WIRESHARK
-if NOT_OS_X
+if NOT_MACOS
mkdir -p $(DESTDIR)$(datadir)/mime/packages
install -m 644 $(srcdir)/wireshark-mime-package.xml $(DESTDIR)$(datadir)/mime/packages/wireshark.xml
mkdir -p $(DESTDIR)$(datadir)/appdata
@@ -1013,7 +1013,7 @@ endif
uninstall-local:
if BUILDING_WIRESHARK
-if NOT_OS_X
+if NOT_MACOS
rm -f $(DESTDIR)$(datadir)/appdata/wireshark.appdata.xml
rm -f $(DESTDIR)$(datadir)/applications/wireshark.desktop
rm -f $(DESTDIR)$(datadir)/applications/wireshark-gtk.desktop
@@ -1059,7 +1059,7 @@ uninstall-hook: update-databases-and-caches-uninstall
#
update-databases-and-caches-common:
if BUILDING_WIRESHARK
-if NOT_OS_X
+if NOT_MACOS
@echo "You may need to run \"ldconfig\" as root"
@echo "You may need to run \"update-desktop-database $(datadir)/applications\""
@echo "You may need to run \"update-mime-database $(datadir)/mime\""
diff --git a/cmakeconfig.h.in b/cmakeconfig.h.in
index cfb01047c0..cf485f0b90 100644
--- a/cmakeconfig.h.in
+++ b/cmakeconfig.h.in
@@ -218,7 +218,7 @@
#cmakedefine HAVE_NTDDNDIS_H 1
/* Define to 1 if you have macOS frameworks */
-#cmakedefine HAVE_OS_X_FRAMEWORKS 1
+#cmakedefine HAVE_MACOS_FRAMEWORKS 1
/* Define to 1 if you have the macOS CFPropertyListCreateWithStream function */
#cmakedefine HAVE_CFPROPERTYLISTCREATEWITHSTREAM 1
diff --git a/configure.ac b/configure.ac
index a5048daa4f..4da9b93646 100644
--- a/configure.ac
+++ b/configure.ac
@@ -517,7 +517,7 @@ AC_SUBST(HAVE_OSX_PACKAGING)
# don't look for Darwin).
#
AC_CHECK_PROG(have_sw_vers, sw_vers, "yes", "no")
-AM_CONDITIONAL(NOT_OS_X, test "x$have_sw_vers" = "xno")
+AM_CONDITIONAL(NOT_MACOS, test "x$have_sw_vers" = "xno")
# Shellcheck
AC_CHECK_PROG(HAVE_SHELLCHECK, shellcheck, "yes", "no")
@@ -1130,11 +1130,11 @@ AC_SUBST(LDFLAGS_SHAREDLIB)
# get version information from plists and thus need Core Foundation
# to process those plists.
#
-have_os_x_frameworks=no
+have_macos_frameworks=no
case "$host_os" in
darwin*)
- have_os_x_frameworks=yes
- AC_DEFINE(HAVE_OS_X_FRAMEWORKS, 1, [Define to 1 if you have macOS frameworks])
+ have_macos_frameworks=yes
+ AC_DEFINE(HAVE_MACOS_FRAMEWORKS, 1, [Define to 1 if you have macOS frameworks])
APPLICATIONSERVICES_FRAMEWORKS="-framework ApplicationServices"
SYSTEMCONFIGURATION_FRAMEWORKS="-framework SystemConfiguration"
COREFOUNDATION_FRAMEWORKS="-framework CoreFoundation"
@@ -1157,7 +1157,7 @@ esac
AC_SUBST(APPLICATIONSERVICES_FRAMEWORKS)
AC_SUBST(SYSTEMCONFIGURATION_FRAMEWORKS)
AC_SUBST(COREFOUNDATION_FRAMEWORKS)
-AM_CONDITIONAL(HAVE_OS_X_FRAMEWORKS, [test "x$have_os_x_frameworks" = "xyes"])
+AM_CONDITIONAL(HAVE_MACOS_FRAMEWORKS, [test "x$have_macos_frameworks" = "xyes"])
#
# If we're running Solaris, and LD_LIBRARY_PATH is defined, add it as a
diff --git a/ui/gtk/webbrowser.c b/ui/gtk/webbrowser.c
index 467a7333f1..7401c10876 100644
--- a/ui/gtk/webbrowser.c
+++ b/ui/gtk/webbrowser.c
@@ -124,7 +124,7 @@
#include <wsutil/unicode-utils.h>
/* if WIN32_LEAN_AND_MEAN is defined, shellapi.h is needed too */
#include <shellapi.h>
-#elif defined (HAVE_OS_X_FRAMEWORKS)
+#elif defined (HAVE_MACOS_FRAMEWORKS)
/* macOS - use Launch Services to start a browser */
#include <CoreFoundation/CoreFoundation.h>
#include <ApplicationServices/ApplicationServices.h>
@@ -159,7 +159,7 @@ browser_open_url (const gchar *url)
return ((intptr_t) ShellExecute (HWND_DESKTOP, _T("open"), utf_8to16(url), NULL, NULL, SW_SHOWNORMAL) > 32);
-#elif defined(HAVE_OS_X_FRAMEWORKS)
+#elif defined(HAVE_MACOS_FRAMEWORKS)
CFStringRef url_CFString;
CFURLRef url_CFURL;
@@ -291,7 +291,7 @@ filemanager_open_directory (const gchar *path)
g_free(xpath);
return (ret > 32);
-#elif defined(HAVE_OS_X_FRAMEWORKS)
+#elif defined(HAVE_MACOS_FRAMEWORKS)
CFStringRef path_CFString;
CFURLRef path_CFURL;
diff --git a/wsutil/CMakeLists.txt b/wsutil/CMakeLists.txt
index 5eca03eddd..2a1f9b0c6f 100644
--- a/wsutil/CMakeLists.txt
+++ b/wsutil/CMakeLists.txt
@@ -80,7 +80,7 @@ if(WIN32)
ENDIF(WIN32)
-if(HAVE_OS_X_FRAMEWORKS)
+if(HAVE_MACOS_FRAMEWORKS)
list(APPEND WSUTIL_FILES cfutils.c)
endif()
diff --git a/wsutil/Makefile.am b/wsutil/Makefile.am
index 920b3f1216..1e59df4c1e 100644
--- a/wsutil/Makefile.am
+++ b/wsutil/Makefile.am
@@ -32,7 +32,7 @@ AM_CPPFLAGS = $(INCLUDEDIRS) $(WS_CPPFLAGS) -DWS_BUILD_DLL \
# Optional headers for ABI checking
wsutil_optional_abi_includes =
-if HAVE_OS_X_FRAMEWORKS
+if HAVE_MACOS_FRAMEWORKS
wsutil_optional_abi_includes += cfutils.h
endif
@@ -160,7 +160,7 @@ libwsutil_la_SOURCES = \
wsjsmn.c \
xtea.c
-if HAVE_OS_X_FRAMEWORKS
+if HAVE_MACOS_FRAMEWORKS
libwsutil_la_SOURCES += cfutils.c cfutils.h
endif
diff --git a/wsutil/os_version_info.c b/wsutil/os_version_info.c
index cbd4025ead..4ad3986e7a 100644
--- a/wsutil/os_version_info.c
+++ b/wsutil/os_version_info.c
@@ -29,7 +29,7 @@
#include <sys/utsname.h>
#endif
-#ifdef HAVE_OS_X_FRAMEWORKS
+#ifdef HAVE_MACOS_FRAMEWORKS
#include <CoreFoundation/CoreFoundation.h>
#include <wsutil/cfutils.h>
#endif
@@ -49,7 +49,7 @@ typedef void (WINAPI *nativesi_func_ptr)(LPSYSTEM_INFO);
* from macOS (we want the macOS version, not the Darwin version, the latter
* being easy to get with uname()).
*/
-#ifdef HAVE_OS_X_FRAMEWORKS
+#ifdef HAVE_MACOS_FRAMEWORKS
/*
* Fetch a string, as a UTF-8 C string, from a dictionary, given a key.
@@ -437,7 +437,7 @@ get_os_version_info(GString *str)
* On *BSD and Darwin/macOS, it's a long string giving
* a build date, config file name, etc., etc., etc..
*/
-#ifdef HAVE_OS_X_FRAMEWORKS
+#ifdef HAVE_MACOS_FRAMEWORKS
/*
* On macOS, report the macOS version number as the OS
* version if we can, and put the Darwin information
@@ -450,7 +450,7 @@ get_os_version_info(GString *str)
/* Failure - just use the Darwin information. */
g_string_append_printf(str, "%s %s", name.sysname, name.release);
}
-#else /* HAVE_OS_X_FRAMEWORKS */
+#else /* HAVE_MACOS_FRAMEWORKS */
/*
* XXX - on Linux, are there any APIs to get the distribution
* name and version number? I think some distributions have
@@ -503,7 +503,7 @@ get_os_version_info(GString *str)
* releases.
*/
g_string_append_printf(str, "%s %s", name.sysname, name.release);
-#endif /* HAVE_OS_X_FRAMEWORKS */
+#endif /* HAVE_MACOS_FRAMEWORKS */
}
#else
g_string_append(str, "an unknown OS");
diff --git a/cmake/modules/FindOS_X_FRAMEWORKS.cmake b/cmake/modules/FindOS_X_FRAMEWORKS.cmake
index 52798c9c6b..119fa84f36 100644
--- a/cmake/modules/FindOS_X_FRAMEWORKS.cmake
+++ b/cmake/modules/FindOS_X_FRAMEWORKS.cmake
@@ -5,7 +5,7 @@
# APPLE_APPLICATION_SERVICES_LIBRARY - ApplicationServices framework
# APPLE_CORE_FOUNDATION_LIBRARY - CoreFoundation frameowkr
# APPLE_SYSTEM_CONFIGURATION_LIBRARY - SystemConfiguration framework
# HAVE_OS_X_FRAMEWORKS - True if we're on macOS
if(APPLE)
@@ -13,8 +13,8 @@ if(APPLE)
# We assume that APPLE means macOS so that we have the macOS
# frameworks.
#
- set(HAVE_OS_X_FRAMEWORKS 1)
- set(OS_X_FRAMEWORKS_FOUND TRUE)
+ set(HAVE_MACOS_FRAMEWORKS 1)
+ set(MACOS_FRAMEWORKS_FOUND TRUE)
FIND_LIBRARY (APPLE_APPLICATION_SERVICES_LIBRARY ApplicationServices)
FIND_LIBRARY (APPLE_CORE_FOUNDATION_LIBRARY CoreFoundation)
FIND_LIBRARY (APPLE_SYSTEM_CONFIGURATION_LIBRARY SystemConfiguration)
@@ -5,7 +5,7 @@
# APPLE_CORE_FOUNDATION_LIBRARY - CoreFoundation frameowkr
# APPLE_SYSTEM_CONFIGURATION_LIBRARY - SystemConfiguration framework
-# HAVE_OS_X_FRAMEWORKS - True if we're on macOS
+# HAVE_MACOS_FRAMEWORKS - True if we're on macOS
if(APPLE)